pub struct Style { /* private fields */ }Expand description
Implementations
impl Style
impl Style
pub const fn fg_color(self, fg: Option<Color>) -> Style
pub const fn fg_color(self, fg: Option<Color>) -> Style
Set foreground color
Examples
let style = anstyle::Style::new().fg_color(Some(anstyle::AnsiColor::Red.into()));pub const fn bg_color(self, bg: Option<Color>) -> Style
pub const fn bg_color(self, bg: Option<Color>) -> Style
Set background color
Examples
let style = anstyle::Style::new().bg_color(Some(anstyle::AnsiColor::Red.into()));pub const fn underline_color(self, underline: Option<Color>) -> Style
pub const fn underline_color(self, underline: Option<Color>) -> Style
Set underline color
Examples
let style = anstyle::Style::new().underline_color(Some(anstyle::AnsiColor::Red.into()));pub const fn effects(self, effects: Effects) -> Style
pub const fn effects(self, effects: Effects) -> Style
Set text effects
Examples
let style = anstyle::Style::new().effects(anstyle::Effects::BOLD | anstyle::Effects::UNDERLINE);pub fn write_to(self, write: &mut dyn Write) -> Result<(), Error>
Available on crate feature std only.
pub fn write_to(self, write: &mut dyn Write) -> Result<(), Error>
std only.Write the ANSI code
pub fn render_reset(self) -> impl Display
pub fn render_reset(self) -> impl Display
Renders the relevant Reset code
Unlike Reset::render, this will elide the code if there is nothing to reset.
pub fn write_reset_to(self, write: &mut dyn Write) -> Result<(), Error>
Available on crate feature std only.
pub fn write_reset_to(self, write: &mut dyn Write) -> Result<(), Error>
std only.Write the relevant Reset code
Unlike Reset::render, this will elide the code if there is nothing to reset.
impl Style
impl Style
impl Style
impl Style
pub const fn get_fg_color(self) -> Option<Color>
pub const fn get_bg_color(self) -> Option<Color>
pub const fn get_underline_color(self) -> Option<Color>
pub const fn get_effects(self) -> Effects